@@ -1,6 +1,9 @@
+extern crate core;
+
 use mime::Mime;
 use std::io::Cursor;
 use std::str::FromStr;
+use thumbnailer::error::ThumbError;
 use thumbnailer::{create_thumbnails, ThumbnailSize};
 
 const VIDEO_BYTES: &'static [u8] = include_bytes!("assets/test.mp4");
@@ -17,9 +20,18 @@ fn it_creates_thumbnails_for_mp4() {
             ThumbnailSize::Large,
         ],
     );
-    #[cfg(feature = "ffmpeg")]
-    result.unwrap();
 
-    #[cfg(not(feature = "ffmpeg"))]
-    assert!(result.is_err())
+    match result {
+        Ok(_) => {
+            assert!(true)
+        }
+        Err(e) => match e {
+            ThumbError::Unsupported(_) => {
+                assert!(true, "ffmpeg is not installed");
+            }
+            e => {
+                panic!("failed to create thumbnails {}", e);
+            }
+        },
+    }
 }
